Enum Request
#[non_exhaustive]pub enum Request<'a> {
Destroy,
Feedback {
surface: WlSurface,
},
}wayland_platform and crate feature client only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Destroy
unbind from the presentation interface
Informs the server that the client will no longer be using this protocol object. Existing objects created by this object are not affected.
This is a destructor, once sent this object cannot be used any longer.
Feedback
request presentation feedback information
Request presentation feedback for the current content submission on the given surface. This creates a new presentation_feedback object, which will deliver the feedback information once. If multiple presentation_feedback objects are created for the same submission, they will all deliver the same information.
For details on what information is returned, see the presentation_feedback interface.
Implementations