Struct WpPresentation

pub struct WpPresentation { /* private fields */ }
Available on crate feature wayland and Linux only.
timed presentation related wl_surface requests

The main feature of this interface is accurate presentation timing feedback to ensure smooth video playback while maintaining audio/video synchronization. Some features use the concept of a presentation clock, which is defined in the presentation.clock_id event.

A content update for a wl_surface is submitted by a wl_surface.commit request. Request ‘feedback’ associates with the wl_surface.commit and provides feedback on the content update, particularly the final realized presentation time.

When the final realized presentation time is available, e.g. after a framebuffer flip completes, the requested presentation_feedback.presented events are sent. The final presentation time can differ from the compositor’s predicted display update time and the update’s target time, especially when the compositor misses its target vertical blanking period.

See also the Event enum for this interface.

Implementations



impl WpPresentation

pub fn destroy(&self)

unbind from the presentation interface

Informs the server that the client will no longer be using this protocol object. Existing objects created by this object are not affected.

pub fn feedback<U, D>( &self, surface: &WlSurface, qh: &QueueHandle<D>, udata: U, ) -> WpPresentationFeedback
where U: Send + Sync + 'static, D: Dispatch<WpPresentationFeedback, U> + 'static,

request presentation feedback information

Request presentation feedback for the current content submission on the given surface. This creates a new presentation_feedback object, which will deliver the feedback information once. If multiple presentation_feedback objects are created for the same submission, they will all deliver the same information.

For details on what information is returned, see the presentation_feedback interface.